@@ -5,10 +5,8 @@
 */
 
 #include "colorscheme.h"
-#include <kconfigwidgets_version.h>
-#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 93, 0)
-#include <KStatefulBrush> // was moved to own header in 5.93.0
-#endif
+
+#include <KStatefulBrush>
 
 ColorScheme::ColorScheme(QQuickItem *parent) :
 QQuickItem(parent)
